@@ -1,8 +1,8 @@
 ###############################################################################
 #Filter.pm
-#Last Change: 2009-01-19
-#Copyright (c) 2009 Marc-Seabstian "Maluku" Lucksch
-#Version 0.8
+#Last Change: 2000-01-02
+#Copyright (c) 2006 Marc-Seabstian "Maluku" Lucksch
+#Version 0.1
 ####################
 #This file is part of the Dotiac::DTL project. 
 #http://search.cpan.org/perldoc?Dotiac::DTL
@@ -18,8 +18,6 @@ package Dotiac::DTL::Filter;
 use strict;
 use warnings;
 require Scalar::Util;
-our $VERSION = 0.8;
-
 sub add {
 	my $value=shift;
 	my $add=shift;
@@ -214,7 +212,7 @@ sub date {
 			$res.=", ";
 			$res.=$t[4]+1;
 			$res.=" ".$datemonths[$t[4]]." ".($t[5]+1900);
-			$res.=sprintf(" %02d:%02d:%02d",$t[2],$t[1],$t[0]);
+			$res.=" ".$t[2].":".$t[1].":".$t[0];
 			my @tt=localtime(0);
 			$tt[2]+=1 if $t[8];
 			$res.=sprintf(" %+05d",$tt[2]*100+$tt[1]);
@@ -419,8 +417,7 @@ sub escapejs {
 	my $value=shift;
 	my $val=$value->repr();
 	$val =~ s/([\n\r\t\f\b"'\\])/$jsescape{$1}/eg;
-	#$val =~ s/([\x00-\x08\x0b\x0e-\x1f\x7f-\x{FFFF}])/'\\u' .sprintf("%04x",ord($1))/eg; #Won't work in Perl 5.6.0
-	$val =~ s/([^\x09\x0a\x0c\x0d\x20-\x7e])/'\\u' .sprintf("%04x",ord($1))/eg;
+        $val =~ s/([\x00-\x08\x0b\x0e-\x1f\x{7f}-\x{ffff}])/'\\u' .sprintf("%04x",ord($1))/eg;
 	$value->set($val);
 	return $value;
 }
@@ -1044,7 +1041,7 @@ sub timesince {
 		$comp=CORE::time();
 	}
 	my $dist=$comp-$val;
-	return Dotiac::DTL::Value->safe("0 $timenames[11]") if $dist < 60;
+	return "0 $timenames[11]" if $dist < 60;
 	my $mi=int($dist/60);
 	my $h=int($mi/60);
 	$mi=$mi%60;
@@ -1086,7 +1083,7 @@ sub timeuntil {
 		$comp=CORE::time();
 	}
 	my $dist=$val-$comp;
-	return Dotiac::DTL::Value->safe("0 $timenames[11]") if $dist < 60;
+	return "0 $timenames[11]" if $dist < 60;
 	my $mi=int($dist/60);
 	my $h=int($mi/60);
 	$mi=$mi%60;
@@ -1850,10 +1847,6 @@ Escapes a Javascript (JSON) String. This will not generate JSON Code out of data
 
 Might escape some more characters than original Django.
 
-On perl 5.6.2 unicode output is not really supported, you will get for example:
-
-	\u00e3\u0093\u00b4 instead of \u4532
-
 =head2 filesizeformat
 
 Returns a number of bytes in bytes, Kb, Mb, Gb or Tb ... This is used to display the size of files/traffic or anything else counted this way to be read by humans
@@ -1956,7 +1949,7 @@ This won't work on EBCDIC Systems for now, sadly.
 
 If you find anything else, please report them.
 
-=head2 join :STRING
+=head2 get_digit :STRING
 
 Joins a list-value by a STRING.
 
@@ -1999,7 +1992,7 @@ Tries to call count() on objects to get the length.
 
 C<undef> (C<none> in python) will be counted as "".
 
-=head2 length_is :LENGTH
+=head2 length_is: LENGTH
 
 Returns 1 if the length of arrays, lists or strings is equal to LENGTH, "" otherwise.
 
@@ -2152,7 +2145,7 @@ For Debug
 
 Uses Data::Dumper instead of pprint
 
-=head2 random
+=head2 last
 
 Returns a random element of a list. (See also C<first> and C<last>)
 
@@ -2165,7 +2158,7 @@ Returns a random element of a list. (See also C<first> and C<last>)
 
 Also returns a random value of a hash.
 
-=head2 removetags :TAGS
+=head2 removetags: TAGS
 
 Removes HTML (XML) TAGS from the value. TAGS is a space seperated list of tags to be removed
 
@@ -2546,7 +2539,7 @@ The returned value is always escaped (if unsafe) and marked safe.
 
 The old verbose format is supported, but I don't trust the implementation. (It works, I don't know why)
 
-=head2 urlencode
+=head2 upper
 
 Converts all characters except wordcharacters, minus, "~" and "/" to be used in an url
 
